@@ -14,6 +14,9 @@ namespace ColorSpace {
 	struct Hsv;
 	struct Hsb;
 	struct HunterLab;
+	struct Hcl;
+	struct OkLab;
+	struct OkLch;
 
 	template <typename TColorSpace>
 	struct IConverter {
@@ -35,6 +38,7 @@ namespace ColorSpace {
 		static const double eps;
 		static const double kappa;
 		static Xyz whiteReference;
+		static void SetWhiteReference(double x, double y, double z);
 	};
 	typedef IConverter<Xyz> XyzConverter;
 
@@ -107,6 +111,27 @@ namespace ColorSpace {
 		static void ToColor(Rgb *color, HunterLab *item);
 	};
 	typedef IConverter<HunterLab> HunterLabConverter;
+	
+	template <>
+	struct IConverter<Hcl> {
+	  static void ToColorSpace(Rgb *color, Hcl *item);
+	  static void ToColor(Rgb *color, Hcl *item);
+	};
+	typedef IConverter<Hcl> HclConverter;
+	
+	template <>
+	struct IConverter<OkLab> {
+	  static void ToColorSpace(Rgb *color, OkLab *item);
+	  static void ToColor(Rgb *color, OkLab *item);
+	};
+	typedef IConverter<OkLab> OkLabConverter;
+	
+	template <>
+	struct IConverter<OkLch> {
+	  static void ToColorSpace(Rgb *color, OkLch *item);
+	  static void ToColor(Rgb *color, OkLch *item);
+	};
+	typedef IConverter<OkLch> OkLchConverter;
 }
 
 #endif // RGB_CONVERTER_H
